@@ -11,7 +11,7 @@ from nomad.engine import DBError
 from nomad.utils import abort, NomadError, NomadIniNotFound
 
 
-__version__ = '1.8'
+__version__ = '1.9'
 
 
 GLOBAL = [
@@ -50,7 +50,10 @@ app = Dispatcher(globaloptions=GLOBAL, middleware=getconfig)
 def init(**opts):
     '''Initialize database migration management
     '''
-    opts['repo'].init_db()
+    try:
+        opts['repo'].init_db()
+    except DBError, e:
+        abort(e)
     print 'Versioning table initialized successfully'
 
 
